@@ -20,6 +20,7 @@ from datetime import datetime
 from typing import Any, Awaitable, Dict, Iterable, List, Optional, Union
 
 import comet_mpm.event
+import comet_mpm.events_from_dataframe
 
 from .connection import MPM_BASE_PATH, REST_API_BASE_PATH, sanitize_url, url_join
 from .constants import (
@@ -194,6 +195,7 @@ class CometMPM:
         to have the full context.
 
         Args:
+            dataframe: the pandas DataFrame to be logged.
             prediction_id_column: this column should have the prediction_id
                 values for the events.
             feature_columns: if provided, this column will be used as the
@@ -203,20 +205,13 @@ class CometMPM:
             output_probability_column: if provided, this column will be used as
                 the output_probability for the events.
         """
-        events = []
-        for row in dataframe.itertuples():
-            prediction_id = str(getattr(row, prediction_id_column))
-            event = comet_mpm.event.Event(prediction_id=prediction_id)
-            if feature_columns is not None:
-                event.input_features = {
-                    key: getattr(row, key) for key in feature_columns
-                }
-            if output_value_column is not None:
-                event.output_value = getattr(row, output_value_column)
-            if output_probability_column is not None:
-                event.output_probability = getattr(row, output_probability_column)
-
-            events.append(event)
+        events = comet_mpm.events_from_dataframe.generate(
+            dataframe,
+            prediction_id_column,
+            feature_columns,
+            output_value_column,
+            output_probability_column,
+        )
 
         return self._log_events(events)
 
